@@ -52,7 +52,7 @@ TerminatorRunTime = R6Class("TerminatorRunTime",
     #'
     #' @return `logical(1)`.
     is_terminated = function(archive) {
-      assert_r6(archive, "Archive")
+      assert_multi_class(archive, c("Archive", "ArchiveAsync"))
       if (is.null(archive$start_time)) return(FALSE)
       d = as.numeric(difftime(Sys.time(), archive$start_time, units = "secs"))
       return(d >= self$param_set$values$secs)
