@@ -233,10 +233,13 @@ expect_dictionary = function(d, contains = NA_character_, min_items = 0L) {
 }
 
 expect_rush_reset = function(rush, type = "kill") {
-  processes = rush$processes
   rush$reset(type = type)
-  expect_list(rush$connector$command(c("KEYS", "*")), len = 0)
-  walk(processes, function(p) p$kill())
+  Sys.sleep(1)
+  keys = rush$connector$command(c("KEYS", "*"))
+  if (!test_list(keys, len = 0)) {
+    stopf("Found keys in redis after reset: %s", keys)
+  }
+  mirai::daemons(0)
 }
 
 flush_redis = function() {
@@ -244,3 +247,9 @@ flush_redis = function() {
   r = redux::hiredis(config)
   r$FLUSHDB()
 }
+
+check_test_results = function(testres) {
+  for (i in seq_along(testres)) {
+    expect_true(testres[[i]], info = names(testres)[i], label = names(testres)[i])
+  }
+}
